==> percona-server-mongodb_4.0.18.orig.tar.gz: percona-server-mongodb-4.0.18-11/src/mongo/base/initializer_function.h <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/base/status.h"
#include "mongo/stdx/functional.h"

namespace mongo {

class InitializerContext;
class DeinitializerContext;

/**
 * An InitializerFunction implements the behavior of an initializer operation.
 *
 * On successful execution, an InitializerFunction returns Status::OK().  It may
 * inspect and mutate the supplied InitializerContext.
 */
typedef stdx::function<Status(InitializerContext*)> InitializerFunction;

/**
* A DeinitializerFunction implements the behavior of a deinitializer operation.
*
* On successful execution, a DeinitializerFunction returns Status::OK(). It may
* inspect and mutate the supplied DeinitializerContext.
*/
typedef stdx::function<Status(DeinitializerContext*)> DeinitializerFunction;


}  // namespace mongo

==> percona-server-mongodb_4.4.16.orig.tar.gz: percona-server-mongodb-4.4.16-16/src/mongo/base/initializer_function.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <functional>

#include "mongo/base/status.h"

namespace mongo {

class InitializerContext;
class DeinitializerContext;

/**
 * An InitializerFunction implements the behavior of an initializer operation.
 *
 * On successful execution, an InitializerFunction returns Status::OK().  It may
 * inspect and mutate the supplied InitializerContext.
 */
typedef std::function<Status(InitializerContext*)> InitializerFunction;

/**
 * A DeinitializerFunction implements the behavior of a deinitializer operation.
 *
 * On successful execution, a DeinitializerFunction returns Status::OK(). It may
 * inspect and mutate the supplied DeinitializerContext.
 */
typedef std::function<Status(DeinitializerContext*)> DeinitializerFunction;


}  // namespace mongo
